fedex.config

Package fedex :: Module config |
[hide private]
[frames] | no frames]

# Module config

source code

The config module contains the FedexConfig class, which is passed to the Fedex API calls. It stores useful information such as your Web Services account numbers and keys.

It is strongly suggested that you create a single FedexConfig object in your project and pass that to the various API calls, rather than create new FedexConfig objects haphazardly. This is merely a design suggestion, treat it as such.

Classes | [hide private]
| FedexConfig Base configuration class that is used for the different Fedex SOAP calls.

Variables | [hide private]
| __package__ = ``'``fedex``'``